@@ -3,7 +3,7 @@ from flask_sqlalchemy import SQLAlchemy
 from flask_migrate import Migrate
 from flask_httpauth import HTTPTokenAuth
 import os
-from .messenger import Messenger
+from polzybackend.messenger import Messenger
 
 
 # initialization
@@ -32,14 +32,21 @@ def create_app(config=None):
     db.init_app(app)
     migrate.init_app(app, db)
 
-    from .main import bp
-    app.register_blueprint(bp)
+    from polzybackend.authenticate import bp as bp_auth
+    app.register_blueprint(bp_auth)
 
-    from .announce import bp as bp_announce
+    from polzybackend.main import bp as bp_main
+    app.register_blueprint(bp_main)
+
+    from polzybackend.announce import bp as bp_announce
     app.register_blueprint(bp_announce)
 
+    # -----------> DEBUG BLUEPRINT
+    from polzybackend.debug import bp as bpDebug
+    app.register_blueprint(bpDebug)
+
     return app
 
 
 
-from . import models
+from polzybackend import models
