@@ -108,8 +108,13 @@ class User(db.Model):
         foreign_keys=[oauth_provider_id],
     )
     company = db.relationship(
-        'Company',
-        foreign_keys=[company_id],
+        'UserToCompany',
+        primaryjoin=and_(
+            id == UserToCompany.user_id,
+            company_id == UserToCompany.company_id,
+        ),
+        uselist=False,
+        #foreign_keys=[company_id],
     )
 
     def __str__(self):
@@ -147,7 +152,7 @@ class User(db.Model):
             raise Exception('User is not assigned to this company')
 
         # set company
-        self.company = company
+        self.company_id = company.id
         db.session.commit()
 
     def to_json(self):
