@@ -16,7 +16,7 @@ def str_id_to_bytes(str_id):
 
 
 def bytes_id_to_str(bytes_id):
-    return uuid.UUID(bytes=bytes_id)
+    return str(uuid.UUID(bytes=bytes_id))
 
 
 def generate_token(length=ACCESS_KEY_LENGTH):
